@@ -1,7 +1,10 @@
+import json
 import logging
 import re
 from abc import ABC
 
+from dbcat.catalog.models import PiiTypes
+
 from piicatcher.log_mixin import LogMixin
 from piicatcher.scanner import ColumnNameScanner, NERScanner, RegexScanner
 
@@ -16,6 +19,15 @@ scan_logger.setLevel(logging.INFO)
 scan_logger.addHandler(logging.NullHandler())
 
 
+# Ref: https://stackoverflow.com/questions/24481852/serialising-an-enum-member-to-json
+class PiiTypeEncoder(json.JSONEncoder):
+    # pylint: disable=method-hidden
+    def default(self, obj):
+        if type(obj) == PiiTypes:
+            return {"__enum__": str(obj)}
+        return json.JSONEncoder.default(self, obj)
+
+
 class NamedObject(ABC, LogMixin):
     def __init__(self, name, include, exclude):
         self._name = name
