@@ -5,11 +5,9 @@ from abc import ABC, abstractmethod
 
 import spacy
 from commonregex import CommonRegex
-
-from piicatcher.piitypes import PiiTypes
+from dbcat.catalog.models import PiiTypes
 
 
-# pylint: disable=too-few-public-methods
 class Scanner(ABC):
     """Scanner abstract class that defines required methods"""
 
